==> zio-aws-mediatailor_3-5.17.124.3-sources.jar: zio/aws/mediatailor/model/TagResourceRequest.scala <==
package zio.aws.mediatailor.model
import zio.aws.mediatailor.model.primitives.__string
import zio.ZIO
import zio.aws.core.BuilderHelper
import scala.jdk.CollectionConverters.*
final case class TagResourceRequest(
    resourceArn: __string,
    tags: Map[__string, __string]
) {
  def buildAwsValue()
      : software.amazon.awssdk.services.mediatailor.model.TagResourceRequest = {
    import TagResourceRequest.zioAwsBuilderHelper.BuilderOps
    software.amazon.awssdk.services.mediatailor.model.TagResourceRequest
      .builder()
      .resourceArn(__string.unwrap(resourceArn): java.lang.String)
      .tags(
        tags
          .map({ case (key, value) =>
            (__string.unwrap(key): java.lang.String) -> (__string
              .unwrap(value): java.lang.String)
          })
          .asJava
      )
      .build()
  }
  def asReadOnly: zio.aws.mediatailor.model.TagResourceRequest.ReadOnly =
    zio.aws.mediatailor.model.TagResourceRequest.wrap(buildAwsValue())
}
object TagResourceRequest {
  private lazy val zioAwsBuilderHelper: BuilderHelper[
    software.amazon.awssdk.services.mediatailor.model.TagResourceRequest
  ] = BuilderHelper.apply
  trait ReadOnly {
    def asEditable: zio.aws.mediatailor.model.TagResourceRequest =
      zio.aws.mediatailor.model.TagResourceRequest(resourceArn, tags)
    def resourceArn: __string
    def tags: Map[__string, __string]
    def getResourceArn: ZIO[Any, Nothing, __string] = ZIO.succeed(resourceArn)
    def getTags: ZIO[Any, Nothing, Map[__string, __string]] = ZIO.succeed(tags)
  }
  private final class Wrapper(
      impl: software.amazon.awssdk.services.mediatailor.model.TagResourceRequest
  ) extends zio.aws.mediatailor.model.TagResourceRequest.ReadOnly {
    override val resourceArn: __string =
      zio.aws.mediatailor.model.primitives.__string(impl.resourceArn())
    override val tags: Map[__string, __string] = impl
      .tags()
      .asScala
      .map({ case (key, value) =>
        zio.aws.mediatailor.model.primitives
          .__string(key) -> zio.aws.mediatailor.model.primitives.__string(value)
      })
      .toMap
  }
  def wrap(
      impl: software.amazon.awssdk.services.mediatailor.model.TagResourceRequest
  ): zio.aws.mediatailor.model.TagResourceRequest.ReadOnly = new Wrapper(impl)
}

==> zio-aws-mediatailor_3-6.20.58.1-sources.jar: zio/aws/mediatailor/model/TagResourceRequest.scala <==
package zio.aws.mediatailor.model
import zio.aws.mediatailor.model.primitives.__string
import zio.ZIO
import zio.aws.core.BuilderHelper
import scala.jdk.CollectionConverters.*
final case class TagResourceRequest(
    resourceArn: __string,
    tags: Map[__string, __string]
) {
  def buildAwsValue()
      : software.amazon.awssdk.services.mediatailor.model.TagResourceRequest = {
    import TagResourceRequest.zioAwsBuilderHelper.BuilderOps
    software.amazon.awssdk.services.mediatailor.model.TagResourceRequest
      .builder()
      .resourceArn(resourceArn: java.lang.String)
      .tags(
        tags
          .map({ case (key, value) =>
            (key: java.lang.String) -> (value: java.lang.String)
          })
          .asJava
      )
      .build()
  }
  def asReadOnly: zio.aws.mediatailor.model.TagResourceRequest.ReadOnly =
    zio.aws.mediatailor.model.TagResourceRequest.wrap(buildAwsValue())
}
object TagResourceRequest {
  private lazy val zioAwsBuilderHelper: BuilderHelper[
    software.amazon.awssdk.services.mediatailor.model.TagResourceRequest
  ] = BuilderHelper.apply
  trait ReadOnly {
    def asEditable: zio.aws.mediatailor.model.TagResourceRequest =
      zio.aws.mediatailor.model.TagResourceRequest(resourceArn, tags)
    def resourceArn: __string
    def tags: Map[__string, __string]
    def getResourceArn: ZIO[Any, Nothing, __string] = ZIO.succeed(resourceArn)
    def getTags: ZIO[Any, Nothing, Map[__string, __string]] = ZIO.succeed(tags)
  }
  private final class Wrapper(
      impl: software.amazon.awssdk.services.mediatailor.model.TagResourceRequest
  ) extends zio.aws.mediatailor.model.TagResourceRequest.ReadOnly {
    override val resourceArn: __string = impl.resourceArn(): __string
    override val tags: Map[__string, __string] = impl
      .tags()
      .asScala
      .map({ case (key, value) =>
        (key: __string) -> (value: __string)
      })
      .toMap
  }
  def wrap(
      impl: software.amazon.awssdk.services.mediatailor.model.TagResourceRequest
  ): zio.aws.mediatailor.model.TagResourceRequest.ReadOnly = new Wrapper(impl)
}
